@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2023  Jean-Philippe Lang
+# Copyright (C) 2006-  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,14 +20,6 @@
 require_relative '../test_helper'
 
 class ProjectsControllerTest < Redmine::ControllerTest
-  fixtures :projects, :versions, :users, :email_addresses, :roles, :members,
-           :member_roles, :issues, :journals, :journal_details,
-           :trackers, :projects_trackers, :issue_statuses,
-           :enabled_modules, :enumerations, :boards, :messages,
-           :attachments, :custom_fields, :custom_values, :time_entries,
-           :wikis, :wiki_pages, :wiki_contents, :wiki_content_versions,
-           :roles, :queries
-
   include Redmine::I18n
 
   def setup
@@ -130,7 +122,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
     }
 
     assert_response :success
-    assert_select 'tr[id=?] td.name span[class=?]', 'project-5', 'icon icon-user my-project'
+    assert_select 'tr[id=?] td.name span[class=?]', 'project-5', 'icon-only icon-user my-project'
   end
 
   def test_index_as_list_should_indent_projects
@@ -252,6 +244,29 @@ class ProjectsControllerTest < Redmine::ControllerTest
     assert_select ".total-for-cf-#{field.id} span.value", :text => '9'
   end
 
+  def test_index_with_last_activity_date_column
+    with_settings :project_list_defaults => {'column_names' => %w(name short_description last_activity_date)} do
+      get :index, :params => {
+        :display_type => 'list'
+      }
+      assert_response :success
+    end
+    assert_equal ['Name', 'Description', 'Last activity'], columns_in_list
+    activity_time = Journal.find(3).created_on
+    assert_select "tr#project-1 td.last_activity_date a[href=?]",
+      project_activity_path(Project.find(1), :from => User.current.time_to_date(activity_time)),
+      :text => format_time(activity_time)
+    assert_select 'tr#project-4 td.last_activity_date', :text => ''
+  end
+
+  def test_index_with_query
+    query = ProjectQuery.find(11)
+    get :index, :params => { :query_id => query.id }
+    assert_response :success
+    assert_select 'h2', :text => query.name
+    assert_select '#sidebar a.query.selected[title=?]', query.description, :text => query.name
+  end
+
   def test_index_should_retrieve_default_query
     query = ProjectQuery.find(11)
     ProjectQuery.stubs(:default).returns query
@@ -260,6 +275,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
       @request.session[:user_id] = user_id
       get :index
       assert_select 'h2', text: query.name
+      assert_select '#sidebar a.query.selected[title=?]', query.description, :text => query.name
     end
   end
 
@@ -732,7 +748,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
           }
         }
       )
-      assert_response 302
+      assert_response :found
     end
     project = Project.order('id desc').first
     assert_equal 'inherited', project.name
@@ -827,7 +843,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
     project = Project.find_by_identifier('ecookbook')
     project.archive
     get(:show, :params => {:id => 'ecookbook'})
-    assert_response 403
+    assert_response :forbidden
     assert_select 'p', :text => /archived/
     assert_not_include project.name, response.body
   end
@@ -837,7 +853,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
     project = Project.find_by_identifier('ecookbook')
     project.archive
     get(:show, :params => {:id => 'ecookbook'})
-    assert_response 403
+    assert_response :forbidden
     assert_select 'a', :text => "Unarchive"
   end
 
@@ -908,13 +924,13 @@ class ProjectsControllerTest < Redmine::ControllerTest
     Project.find(1).close
     @request.session[:user_id] = 2 # manager
     get(:settings, :params => {:id => 1})
-    assert_response 403
+    assert_response :forbidden
   end
 
   def test_settings_should_be_denied_for_anonymous_on_closed_project
     Project.find(1).close
     get(:settings, :params => {:id => 1})
-    assert_response 403
+    assert_response :forbidden
   end
 
   def test_settings_should_accept_version_status_filter
@@ -1003,7 +1019,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
     role.permissions = []
     role.save
     get(:settings, :params => {:id => project.id})
-    assert_response 403
+    assert_response :forbidden
 
     role.add_permission! :manage_repository, :manage_boards, :manage_project_activities
     get(:settings, :params => {:id => project.id})
@@ -1093,7 +1109,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
         }
       }
     )
-    assert_response 403
+    assert_response :forbidden
     assert_equal 'eCookbook', Project.find(1).name
   end
 
@@ -1108,7 +1124,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
         }
       }
     )
-    assert_response 403
+    assert_response :forbidden
     assert_equal 'eCookbook', Project.find(1).name
   end
 
@@ -1126,7 +1142,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
         }
       }
     )
-    assert_response 302
+    assert_response :found
     assert_match /Successful update/, flash[:notice]
   end
 
@@ -1308,7 +1324,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
           :confirm => 'ecookbook'
         }
       )
-      assert_response 403
+      assert_response :forbidden
     end
     assert Project.find(1)
   end
@@ -1316,7 +1332,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
   def test_bulk_destroy_should_require_admin
     @request.session[:user_id] = 2 # non-admin
     delete :bulk_destroy, params: { ids: [1, 2], confirm: 'Yes' }
-    assert_response 403
+    assert_response :forbidden
   end
 
   def test_bulk_destroy_should_require_confirmation
@@ -1326,7 +1342,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
     end
     assert Project.find(1)
     assert Project.find(2)
-    assert_response 200
+    assert_response :ok
   end
 
   def test_bulk_destroy_should_delete_projects
@@ -1403,7 +1419,7 @@ class ProjectsControllerTest < Redmine::ControllerTest
   def test_get_copy_with_invalid_source_should_respond_with_404
     @request.session[:user_id] = 1
     get(:copy, :params => {:id => 99})
-    assert_response 404
+    assert_response :not_found
   end
 
   def test_get_copy_should_preselect_custom_fields
