@@ -20,12 +20,6 @@
 require_relative '../../test_helper'
 
 class Redmine::ApiTest::IssueCategoriesTest < Redmine::ApiTest::Base
-  fixtures :projects, :users, :issue_categories, :issues,
-           :roles,
-           :member_roles,
-           :members,
-           :enabled_modules
-
   test "GET /projects/:project_id/issue_categories.xml should return the issue categories" do
     get '/projects/1/issue_categories.xml', :headers => credentials('jsmith')
     assert_response :success
@@ -62,7 +56,7 @@ class Redmine::ApiTest::IssueCategoriesTest < Redmine::ApiTest::Base
         :params => {:issue_category => {:name => ''}},
         :headers => credentials('jsmith'))
     end
-    assert_response :unprocessable_entity
+    assert_response :unprocessable_content
     assert_equal 'application/xml', @response.media_type
 
     assert_select 'errors error', :text => "Name cannot be blank"
@@ -87,7 +81,7 @@ class Redmine::ApiTest::IssueCategoriesTest < Redmine::ApiTest::Base
         :params => {:issue_category => {:name => ''}},
         :headers => credentials('jsmith'))
     end
-    assert_response :unprocessable_entity
+    assert_response :unprocessable_content
     assert_equal 'application/xml', @response.media_type
 
     assert_select 'errors error', :text => "Name cannot be blank"
